Folder
======

.. currentmodule:: wwt_data_formats.folder

.. autoclass:: Folder
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Folder.browseable
      ~Folder.children
      ~Folder.group
      ~Folder.msr_community_id
      ~Folder.msr_component_id
      ~Folder.name
      ~Folder.permission
      ~Folder.searchable
      ~Folder.sub_type
      ~Folder.thumbnail
      ~Folder.type
      ~Folder.url

   .. rubric:: Methods Summary

   .. autosummary::

      ~Folder.to_xml

   .. rubric:: Attributes Documentation

   .. autoattribute:: browseable
   .. autoattribute:: children
   .. autoattribute:: group
   .. autoattribute:: msr_community_id
   .. autoattribute:: msr_component_id
   .. autoattribute:: name
   .. autoattribute:: permission
   .. autoattribute:: searchable
   .. autoattribute:: sub_type
   .. autoattribute:: thumbnail
   .. autoattribute:: type
   .. autoattribute:: url

   .. rubric:: Methods Documentation

   .. automethod:: to_xml
